@@ -1,4 +1,4 @@
-import control as ct
+import frccontrol as fct
 import numpy as np
 import scipy as sp
 
@@ -14,7 +14,7 @@ def kalmd(sys, Q, R):
     Returns:
     K -- numpy.array(states x outputs), Kalman gain matrix.
     """
-    if np.linalg.matrix_rank(ct.obsv(sys.A, sys.C)) < sys.A.shape[0]:
+    if np.linalg.matrix_rank(fct.obsv(sys.A, sys.C)) < sys.A.shape[0]:
         print(f"Warning: The system is unobservable\n\nA = {sys.A}\nC = {sys.C}\n")
 
     P = sp.linalg.solve_discrete_are(a=sys.A.T, b=sys.C.T, q=Q, r=R)
